==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/GetApnsVoipSandboxChannelRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetApnsVoipSandboxChannelRequest(applicationId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetApnsVoipSandboxChannelRequest = {
    import GetApnsVoipSandboxChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetApnsVoipSandboxChannelRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.pinpoint.model.GetApnsVoipSandboxChannelRequest.ReadOnly =
    zio.aws.pinpoint.model.GetApnsVoipSandboxChannelRequest
      .wrap(buildAwsValue())
}
object GetApnsVoipSandboxChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetApnsVoipSandboxChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetApnsVoipSandboxChannelRequest =
      zio.aws.pinpoint.model.GetApnsVoipSandboxChannelRequest(applicationId)
    def applicationId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetApnsVoipSandboxChannelRequest
  ) extends zio.aws.pinpoint.model.GetApnsVoipSandboxChannelRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetApnsVoipSandboxChannelRequest
  ): zio.aws.pinpoint.model.GetApnsVoipSandboxChannelRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/GetApnsVoipSandboxChannelRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetApnsVoipSandboxChannelRequest(applicationId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetApnsVoipSandboxChannelRequest = {
    import GetApnsVoipSandboxChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetApnsVoipSandboxChannelRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.pinpoint.model.GetApnsVoipSandboxChannelRequest.ReadOnly =
    zio.aws.pinpoint.model.GetApnsVoipSandboxChannelRequest
      .wrap(buildAwsValue())
}
object GetApnsVoipSandboxChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetApnsVoipSandboxChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetApnsVoipSandboxChannelRequest =
      zio.aws.pinpoint.model.GetApnsVoipSandboxChannelRequest(applicationId)
    def applicationId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetApnsVoipSandboxChannelRequest
  ) extends zio.aws.pinpoint.model.GetApnsVoipSandboxChannelRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetApnsVoipSandboxChannelRequest
  ): zio.aws.pinpoint.model.GetApnsVoipSandboxChannelRequest.ReadOnly =
    new Wrapper(impl)
}
